#!/bin/bash
set -ex 
set -e

# Input value
#       . $1 : serial device
#       . $2 : -silent   "silent mode"
#       . $3 : elf

# Exit value : 
#       . 0 : target not booted
#       . 1 : target booted
#       . 2 : target booted, M4 offline
#       . 3 : target booted, M4 running
#       . 255 : bad parameter
#       . 254 : bad serial device 

SILENT=false

if [ $# -eq 3 ]
then
    if [ $2 != "-silent" ]
    then
        echo "$0: invalid parameter"
        echo "   $0 SerialDevice [-silent]"
        exit 255
    else
        SILENT=true
    fi
else
    if [ $# -ne 1 -o $# -ne 3 ] 
    then
        echo "$0: invalid parameter"
        echo "   $0 SerialDevice BinaryName"
        exit 255
    fi
fi


myEcho() {

    if [ $SILENT != true ]
    then
        echo $*
    fi

}


if [ $# -eq 1 -o $# -eq 2 -o $# -eq 3 ]
then

    if [ ! -c $1 ]
    then
        myEcho  "$1 is not present or is not a character-special file." 
        exit 254
    fi

    cd /tmp
    rm -f state

    # Need to wait console closure made by the ide
    sleep 1
    
    /usr/bin/rz --zmodem > $1  < $1  &  
    
#    {    
#        echo -e "root\r" 
#        sleep 1
#    } > $1   

    
    {    
        echo -e "\r" 
        echo -e "sz -b /sys/class/remoteproc/remoteproc0/state  > /dev/ttyS3  < /dev/ttyS3 \r" 
        sleep 1
    } > $1   

 
    if [ ! -f /tmp/state ]
    then
        sleep 1
        echo "wait for state..." 
    fi
    jobs
    kill %1
 

    if [ -f /tmp/state ]
    then
        STATE=`cat /tmp/state`
        # target booted
        RET=1
        if [ $STATE == offline ]
        then
            RET=2
            myEcho "Linux Target booted, M4 offline."
        else
            if [ $STATE == running ]
            then
                RET=3
                
                cd /tmp
    			rm -f /tmp/firmware
    			
                /usr/bin/rz --zmodem > $1  < $1  &
                {    
                     echo -e "sz -b /sys/class/remoteproc/remoteproc0/firmware  > /dev/ttyS3  < /dev/ttyS3 \r" 
                     sleep 1
                } > $1 

                if [ ! -f /tmp/state ]
                then
                    sleep 1
                    echo "wait for firmware..." 
                fi
                  
                FIRMWARE=`cat /tmp/firmware`
                myEcho "Linux Target booted, M4 running "
                if [ $FIRMWARE == $3 ]
                then
                    RET=4
                fi
            fi
        fi
    else
        RET=0
        myEcho "Linux Target not booted, or Console already connected."
    fi

 #   sleep 1
   
 #   /usr/bin/pkill rz   2>/dev/null    
jobs
kill %1

    exit $RET
fi
